# -*- coding: utf-8 -*-
"""
capivara
~~~~~~~~
:copyright: (c) 2016 by Raphael Amorim.
"""
from .api import init

__title__ = 'capivara'
__version__ = '0.0.1'
__author__ = 'Raphael Amorim'
__license__ = 'Apache License 2.0'
__copyright__ = 'Copyright 2016 Raphael Amorim'



import sys, os
import subprocess, json

# TODO: on install donwload and install phantomjs binary

class _capivara(object):

    def __init__(self, port):
        super(_capivara, self).__init__()
        self.port = port

        self.file_init = self.mountInit(str(port))
        self.file_exit = self.mountExit()

    def __call__(self, func):
        return self.execute()

    def mountInit(self, port):
        procedure_init = open('procedures/init.js', 'r')
        init = [
            str(procedure_init.read()),
            "page.open('http://127.0.0.1:{}'".format(port),
            ",function(s){ var element = page.evaluate(function () {", ]

        procedure_init.close()
        return "".join(init)

    def mountExit(self):
        procedure_end = open('procedures/end.js', 'r')
        exit = str(procedure_end.read())
        procedure_end.close()
        return exit

    def querySelector(self, selector=None):
        file = open('script.js','w')
        file.seek(0)
        file.truncate()
        file.write(self.file_init)
        file.write("return document.querySelector('{}');".format(str(selector), "{}"))
        file.write("}); element = normalizeElement(element);")
        file.write(self.file_exit)
        file.close()

        process = subprocess.Popen('phantomjs script.js', shell=True,
            stdout=subprocess.PIPE, stderr=subprocess.STDOUT)

        output, error = process.communicate()
        dom_object = json.loads(output)

        if not error:
            return dom_object
        else:
            raise ProcessException(command, error, output)


def init(port=8000):
    return _capivara(port)



#!/usr/bin/env python

import sys
from setuptools import setup

setup(
    name='capivara',
    version='1.0.0',
    description='Generates & Obtain DOM (Document Object Model)',
    author='Raphael Amorim',
    author_email='rapha850@gmail',
    keywords='dom javascript object model development',
    url='https://github.com/raphamorim/capivara',
    packages=['capivara'],
    install_requires=['nose'],
    include_package_data=True,
    license='Apache 2.0',
    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
    ],
)